﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using CDays2013.InAppPurchase.Resources;

#if DEBUG
using MockIAPLib;
using Store = MockIAPLib;
#else
using Windows.ApplicationModel.Store;
#endif

namespace CDays2013.InAppPurchase
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();
            Loaded += MainPage_Loaded;

            SetupMockIAP();
        }

        private void SetupMockIAP()
        {
            #if DEBUG
            MockIAP.Init();

            MockIAP.RunInMockMode(true);
            MockIAP.SetListingInformation(1, "en-US", "Cool product", "10.0 €", "CoolProduct");

            // Add some more items manually.
            ProductListing p = new ProductListing
            {
                Name = "Cool product",
                ProductId = "CoolProduct",
                ProductType = Windows.ApplicationModel.Store.ProductType.Durable,
                Description = "A cool product",
                FormattedPrice = "10.00 €",
                Tag = string.Empty
            };

            MockIAP.AddProductListing("CoolProduct", p);

            // Add some more items manually.
            ProductListing p2 = new ProductListing
            {
                Name = "Cool product consumable",
                ProductId = "CoolProductConsumable",
                ProductType = Windows.ApplicationModel.Store.ProductType.Consumable,
                Description = "A cool consumable product",
                FormattedPrice = "5.00 €",
                Tag = string.Empty
            };

            MockIAP.AddProductListing("CoolProductConsumable", p2);
#endif
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            if (CurrentApp.LicenseInformation.ProductLicenses.ContainsKey("CoolProduct"))
            {
                ProductLicense license = CurrentApp.LicenseInformation.ProductLicenses["CoolProduct"];
                if (license.IsActive)
                {
                    DoSomethingCool.IsEnabled = true;
                }
                else
                {
                    DoSomethingCool.IsEnabled = false;
                }
            }

            if (CurrentApp.LicenseInformation.ProductLicenses.ContainsKey("CoolProductConsumable"))
            {
                ProductLicense license = CurrentApp.LicenseInformation.ProductLicenses["CoolProductConsumable"];
                if (license.IsActive)
                {
                    Consume.IsEnabled = true;
                }
                else
                {
                    Consume.IsEnabled = false;
                }
            }
        }

        private async void OnListStuffClicked(object sender, RoutedEventArgs e)
        {
            ListingInformation listing = await CurrentApp.LoadListingInformationAsync();
            List<ProductListing> productListings = listing.ProductListings.Values.ToList();

            Purchases.ItemsSource = productListings;
        }

        private async void OnSelectedPurchaseChanged(object sender, SelectionChangedEventArgs e)
        {
            ProductListing selectedPurchase = Purchases.SelectedItem as ProductListing;
            await CurrentApp.RequestProductPurchaseAsync(selectedPurchase.ProductId, true);


            if (selectedPurchase.ProductId == "CoolProduct")
            {
                DoSomethingCool.IsEnabled = true;
            }
            else if (selectedPurchase.ProductId == "CoolProductConsumable")
            {
                Consume.IsEnabled = true;
            }

        }

        private void OnDoSomethingCoolClicked(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Cool!");
        }

        private void OnConsumeButtonClicked(object sender, RoutedEventArgs e)
        {
            var licenses = CurrentApp.LicenseInformation.ProductLicenses;
            if (licenses.ContainsKey("CoolProductConsumable"))
            {
                ProductLicense productLicense = licenses["CoolProductConsumable"];
                CurrentApp.ReportProductFulfillment(productLicense.ProductId);
            }
            MessageBox.Show("Used!");
            Consume.IsEnabled = false;
        }
    }
}